==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/zh/Filter.js <==
({
	"clearFilterDialogTitle": "清除过滤器",
	"filterDefDialogTitle": "过滤器",
	"ruleTitleTemplate": "规则 ${0}",
	
	"conditionEqual": "等于",
	"conditionNotEqual": "不等于",
	"conditionLess": "小于",
	"conditionLessEqual": "小于或等于",
	"conditionLarger": "大于",
	"conditionLargerEqual": "大于或等于",
	"conditionContains": "包含",
	"conditionIs": "是",
	"conditionStartsWith": "开始于",
	"conditionEndWith": "结束于",
	"conditionNotContain": "不包含",
	"conditionIsNot": "非",
	"conditionNotStartWith": "不是开始于",
	"conditionNotEndWith": "不是结束于",
	"conditionBefore": "先于",
	"conditionAfter": "后于",
	"conditionRange": "范围",
	"conditionIsEmpty": "为空",
	
	"all": "全部",
	"any": "任何",
	"relationAll": "所有规则",
	"waiRelAll": "符合以下所有规则：",
	"relationAny": "任何规则",
	"waiRelAny": "符合以下任何规则：",
	"relationMsgFront": "符合",
	"relationMsgTail": "",
	"and": "和",
	"or": "或",
	
	"addRuleButton": "添加规则",
	"waiAddRuleButton": "添加新规则",
	"removeRuleButton": "除去规则",
	"waiRemoveRuleButtonTemplate": "除去规则 ${0}",
	
	"cancelButton": "取消",
	"waiCancelButton": "取消该对话",
	"clearButton": "清除",
	"waiClearButton": "清除过滤器",
	"filterButton": "过滤器",
	"waiFilterButton": "提交过滤器",
	
	"columnSelectLabel": "列",
	"waiColumnSelectTemplate": "规则 ${0} 的列",
	"conditionSelectLabel": "条件",
	"waiConditionSelectTemplate": "规则 ${0} 的条件",
	"valueBoxLabel": "值",
	"waiValueBoxTemplate": "将规则 ${0} 的值输入过滤器",
	
	"rangeTo": "到",
	"rangeTemplate": "从 ${0} 到 ${1}",
	
	"statusTipHeaderColumn": "列",
	"statusTipHeaderCondition": "规则",
	"statusTipTitle": "过滤器栏",
	"statusTipMsg": "单击此处的过滤器栏以过滤 ${0} 中的值。",
	"anycolumn": "任何列",
	"statusTipTitleNoFilter": "过滤器栏",
	"statusTipTitleHasFilter": "过滤器",
	"statusTipRelPre": "符合",
	"statusTipRelPost": "规则。",
	
	"defaultItemsName": "项目",
	"filterBarMsgHasFilterTemplate": "显示的 ${1} ${2} 的 ${0}。",
	"filterBarMsgNoFilterTemplate": "未使用过滤器",
	
	"filterBarDefButton": "定义过滤器",
	"waiFilterBarDefButton": "过滤表",
	"a11yFilterBarDefButton": "过滤器...",
	"filterBarClearButton": "清除过滤器",
	"waiFilterBarClearButton": "清除过滤器",
	"closeFilterBarBtn": "关闭过滤器栏",
	
	"clearFilterMsg": "该操作将除去过滤器并显示所有现有记录。",
	"anyColumnOption": "任何列",
	
	"trueLabel": "True",
	"falseLabel": "False"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/zh/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "清除过滤器",
	"filterDefDialogTitle": "过滤器",
	"ruleTitleTemplate": "规则 ${0}",
	
	"conditionEqual": "等于",
	"conditionNotEqual": "不等于",
	"conditionLess": "小于",
	"conditionLessEqual": "小于或等于",
	"conditionLarger": "大于",
	"conditionLargerEqual": "大于或等于",
	"conditionContains": "包含",
	"conditionIs": "是",
	"conditionStartsWith": "开始于",
	"conditionEndWith": "结束于",
	"conditionNotContain": "不包含",
	"conditionIsNot": "非",
	"conditionNotStartWith": "不是开始于",
	"conditionNotEndWith": "不是结束于",
	"conditionBefore": "先于",
	"conditionAfter": "后于",
	"conditionRange": "范围",
	"conditionIsEmpty": "为空",
	
	"all": "全部",
	"any": "任何",
	"relationAll": "所有规则",
	"waiRelAll": "符合以下所有规则：",
	"relationAny": "任何规则",
	"waiRelAny": "符合以下任何规则：",
	"relationMsgFront": "符合",
	"relationMsgTail": "",
	"and": "和",
	"or": "或",
	
	"addRuleButton": "添加规则",
	"waiAddRuleButton": "添加新规则",
	"removeRuleButton": "除去规则",
	"waiRemoveRuleButtonTemplate": "除去规则 ${0}",
	
	"cancelButton": "取消",
	"waiCancelButton": "取消该对话",
	"clearButton": "清除",
	"waiClearButton": "清除过滤器",
	"filterButton": "过滤器",
	"waiFilterButton": "提交过滤器",
	
	"columnSelectLabel": "列",
	"waiColumnSelectTemplate": "规则 ${0} 的列",
	"conditionSelectLabel": "条件",
	"waiConditionSelectTemplate": "规则 ${0} 的条件",
	"valueBoxLabel": "值",
	"waiValueBoxTemplate": "将规则 ${0} 的值输入过滤器",
	
	"rangeTo": "到",
	"rangeTemplate": "从 ${0} 到 ${1}",
	
	"statusTipHeaderColumn": "列",
	"statusTipHeaderCondition": "规则",
	"statusTipTitle": "过滤器栏",
	"statusTipMsg": "单击此处的过滤器栏以过滤 ${0} 中的值。",
	"anycolumn": "任何列",
	"statusTipTitleNoFilter": "过滤器栏",
	"statusTipTitleHasFilter": "过滤器",
	"statusTipRelAny": "与任何规则匹配。",
	"statusTipRelAll": "与所有规则匹配。",
	
	"defaultItemsName": "项目",
	"filterBarMsgHasFilterTemplate": "显示的 ${1} ${2} 的 ${0}。",
	"filterBarMsgNoFilterTemplate": "未使用过滤器",
	
	"filterBarDefButton": "定义过滤器",
	"waiFilterBarDefButton": "过滤表",
	"a11yFilterBarDefButton": "过滤器...",
	"filterBarClearButton": "清除过滤器",
	"waiFilterBarClearButton": "清除过滤器",
	"closeFilterBarBtn": "关闭过滤器栏",
	
	"clearFilterMsg": "该操作将除去过滤器并显示所有现有记录。",
	"anyColumnOption": "任何列",
	
	"trueLabel": "True",
	"falseLabel": "False"
})
//end v1.x content
);
